MethodChannelUnityDesktopEmbedder class
- Inheritance
-
- Object
- PlatformInterface
- UnityDesktopEmbedderPlatform
- MethodChannelUnityDesktopEmbedder
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- methodChannel → MethodChannel
-
final
-
onEvent
→ Stream<
Map< String, dynamic> > -
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dispose(
) → Future< void> -
override
-
initialize(
{required int width, required int height, required String executablePath, String? shmName, String? semName}) → Future< int> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited