UnityDesktopEmbedderPlatform class abstract
- Inheritance
-
- Object
- PlatformInterface
- UnityDesktopEmbedderPlatform
- Implementers
Constructors
- UnityDesktopEmbedderPlatform()
- Constructs a UnityDesktopEmbedderPlatform.
Properties
Methods
-
dispose(
) → Future< void> -
initialize(
{required int width, required int height, required String executablePath, String? shmName, String? semName}) → Future< int> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ UnityDesktopEmbedderPlatform
-
The default instance of UnityDesktopEmbedderPlatform to use.
Defaults to MethodChannelUnityDesktopEmbedder.
getter/setter pair